==> haskell-cborg-0.2.9.0-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cborg
version:              0.2.9.0
visibility:           public
id:                   cborg-0.2.9.0-CjGynlrZPDH1DqXaqTGIcK
key:                  cborg-0.2.9.0-CjGynlrZPDH1DqXaqTGIcK
license:              BSD-3-Clause
copyright:
    2015-2019 Duncan Coutts,
    2015-2019 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
synopsis:             Concise Binary Object Representation (CBOR)
description:
    This package provides an efficient implementation of the Concise
    Binary Object Representation (CBOR), as specified by
    [RFC 7049](https://tools.ietf.org/html/rfc7049).

    If you are looking for a library for serialisation of Haskell values,
    have a look at the [serialise](/package/serialise) package, which is
    built upon this library.

    An implementation of the standard bijection between CBOR and JSON is
    provided by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility
    for working with CBOR data.

    This package was formerly known as @binary-serialise-cbor@.

category:             Codec
abi:                  fdec92c950337a6783e8ac48836efa1e
exposed:              True
exposed-modules:
    Codec.CBOR Codec.CBOR.ByteArray Codec.CBOR.ByteArray.Sliced
    Codec.CBOR.Decoding Codec.CBOR.Encoding Codec.CBOR.FlatTerm
    Codec.CBOR.Magic Codec.CBOR.Pretty Codec.CBOR.Read Codec.CBOR.Term
    Codec.CBOR.Write

hidden-modules:       Codec.CBOR.ByteArray.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cborg-0.2.9.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cborg-0.2.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg
hs-libraries:         HScborg-0.2.9.0-CjGynlrZPDH1DqXaqTGIcK
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 ghc-bignum-1.2 ghc-prim-0.8.0
    half-0.3.1-LKt7slib8je94L7B8JIQZT
    primitive-0.7.4.0-1hjisjTIkm1Ju7TlHVggBl text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-cborg/html/cborg.haddock
haddock-html:         /usr/share/doc/haskell-cborg/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cborg-0.2.9.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cborg
version:              0.2.9.0
visibility:           public
id:                   cborg-0.2.9.0-BZoFQ20pvIXBegBretBcdJ
key:                  cborg-0.2.9.0-BZoFQ20pvIXBegBretBcdJ
license:              BSD-3-Clause
copyright:
    2015-2019 Duncan Coutts,
    2015-2019 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
synopsis:             Concise Binary Object Representation (CBOR)
description:
    This package provides an efficient implementation of the Concise
    Binary Object Representation (CBOR), as specified by
    [RFC 7049](https://tools.ietf.org/html/rfc7049).

    If you are looking for a library for serialisation of Haskell values,
    have a look at the [serialise](/package/serialise) package, which is
    built upon this library.

    An implementation of the standard bijection between CBOR and JSON is
    provided by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility
    for working with CBOR data.

    This package was formerly known as @binary-serialise-cbor@.

category:             Codec
abi:                  b55cc069e153f465bce0726b210a1bc5
exposed:              True
exposed-modules:
    Codec.CBOR Codec.CBOR.ByteArray Codec.CBOR.ByteArray.Sliced
    Codec.CBOR.Decoding Codec.CBOR.Encoding Codec.CBOR.FlatTerm
    Codec.CBOR.Magic Codec.CBOR.Pretty Codec.CBOR.Read Codec.CBOR.Term
    Codec.CBOR.Write

hidden-modules:       Codec.CBOR.ByteArray.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cborg-0.2.9.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cborg-0.2.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg
hs-libraries:         HScborg-0.2.9.0-BZoFQ20pvIXBegBretBcdJ
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 ghc-bignum-1.2 ghc-prim-0.8.0
    half-0.3.1-IptsrnsqsMaJKU0FfRAFm8
    primitive-0.7.4.0-I9XTAmFqErC1hXdXvvNzkS text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-cborg/html/cborg.haddock
haddock-html:         /usr/share/doc/haskell-cborg/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
